@@ -12,7 +12,7 @@ use Scalar::Util qw(looks_like_number);
 use Statistics::Lite qw(count max mean min sum);
 use List::AllUtils qw(sum0);
 use base qw(Statistics::Data);
-$Statistics::ANOVA::VERSION = '0.09';
+$Statistics::ANOVA::VERSION = '0.091';
 
 =head1 NAME
 
@@ -20,11 +20,11 @@ Statistics::ANOVA - Parametric and nonparametric 1-way analyses of variance for
 
 =head1 VERSION
 
-This is documentation for B<Version 0.09> of Statistics::ANOVA.
+This is documentation for B<Version 0.091> of Statistics::ANOVA.
 
 =head1 SYNOPSIS
 
- use Statistics::ANOVA 0.09;
+ use Statistics::ANOVA 0.091;
  my $aov = Statistics::ANOVA->new();
 
  # Some data:
@@ -143,7 +143,7 @@ you do not mix the methods, e.g., send a bit of a hashref, plus a bit of an aref
 
 =back
 
-The reason for all these options is that there are so many to be found in Perl's Statistics modules (so many it is practically and intuitively possible to make and value) that it's a cost and pain to traverse them; so multiple structures are permitted and, hopefully, handled appropriately. So, namely, you can load:
+The reason for all these options is that there are so many in Perl's Statistics modules (so many it is practically and intuitively possible to make and value) that it's a cost and pain to traverse them; so multiple structures are permitted and, hopefully, handled appropriately. So, namely, you can load:
 
 =over
 
@@ -316,7 +316,7 @@ Note that the contrast coefficients are calculated directly from the values of t
 =cut
 
 sub _aov_indep_param_ord_linear {
-    my ( $self, $data, %args ) = @_;
+    my ( $self, $data ) = @_;
 
     my ( $ss_w, $df_w, $desc, $grand_mean ) = _sumsq_indep_param_ord($data);
 
@@ -341,7 +341,7 @@ sub _aov_indep_param_ord_linear {
 }
 
 sub _aov_indep_param_ord_nonlinear {
-    my ( $self, $data, %args ) = @_;
+    my ( $self, $data ) = @_;
 
     my (
         $f_value, $levels, $ss_l, $ms_w,       $ss_w,
@@ -426,11 +426,6 @@ By default, the method accounts for and corrects for ties, but if C<correct_ties
 
 sub _aov_indep_dfree_ord {
     my ( $self, $data, %args ) = @_;
-    eval { require Statistics::ANOVA::JT; };
-    croak
-'Don\'t know how to do non-parametric ANOVA for independent levels: You might need to install Statistics:ANOVA::JT on this machine'
-      if $@;
-
     my $j_value = _calc_j_value($data);
     my ( $j_var, $exp ) = _calc_jvar( $data, $args{'correct_ties'} );
     my $z_value = ( $j_value - $exp ) / sqrt($j_var);
@@ -461,7 +456,7 @@ sub _calc_j_value {
             }
         );
 
- # Use the ranks to calculate the pair of Mann-Whitney Us for each paired group:
+     # Use ranks to calculate the pair of Mann-Whitney Us for each paired group:
         my ( $n1, $n2 ) =
           ( $data->{ $pairs->[0] }->count, $data->{ $pairs->[1] }->count )
           ;    # get Ns per group in the pair
@@ -474,14 +469,13 @@ sub _calc_j_value {
               ( ( $n * ( $n + 1 ) ) / 2 ) -
               sum( @{ $ranks_href->{$_} } );
         }
-        $j_value +=
-          max(@us);    # Accumulate J-statistic with maximum of the 2 U-values
+        $j_value += max(@us);    # Accumulate J with max of the 2 U-values
     }
     return $j_value;
 }
 
 sub _calc_jvar {
-    my ( $data, $corect_ties ) = @_;
+    my ( $data, $correct_ties ) = @_;
     my $n     = 0;
     my $nj    = 0;
     my $sum_n = 0;
@@ -498,7 +492,7 @@ sub _calc_jvar {
     }
     my $exp = ( $sum_n**2 - $nj ) / 4;
     my $var;
-    if ( defined $corect_ties and $corect_ties == 0 ) {
+    if ( defined $correct_ties and $correct_ties == 0 ) {
         $var = ( $sum_n**2 * ( 2 * $sum_n + 3 ) - $v ) / 72;
     }
     else {
@@ -631,10 +625,6 @@ sub _chi_by_ties {
     return $chi;
 }
 
-sub _definitely_no {
-    return ( defined $_[0] and $_[0] == 0 ) ? 1 : 0;
-}
-
 sub _aov_rmdep_cat_dfree {
     my ( $self, $data, $n, $levels, $correct_ties ) = @_;
     my ( $sumsq, $xtied ) =
@@ -698,8 +688,10 @@ Hollander and Wolfe (1999) describe how Page's I<L>-statistic is directly relate
 sub _sumsqinc_ranks_within {
     my ($ranks) = _ranks_within(@_);
     my $c = 0;
-    return sum0( map { ++$c * $ranks->{$_} }
-          sort { $a <=> $b } keys %{$ranks} );
+    return sum0(
+        map  { ++$c * $ranks->{$_} }
+        sort { $a <=> $b } keys %{$ranks}
+    );
 }
 
 sub _aov_rmdep_ord_dfree {
@@ -753,12 +745,12 @@ All methods return nothing but the class object after feeding it with the releva
 
  $aov->{'f_value'} (or $aov->{'chi_value'}, $aov->{'h_value'}, $aov->{'j_value'}, $aov->{'l_value'} and/or $aov->{'z_value'})
  $aov->{'p_value'} : associated with the test statistic
- $aov->{'df_b'} : the between-groups or treatment or numerator degree(s) of freedom
- $aov->{'df_w'} : the within-groups or error or denominator degree(s) of freedom (also given with F-equivalent Friedman test)
- $aov->{'ss_b'} : between-groups or treatment sum of squares
- $aov->{'ss_w'} : within-groups or error sum of squares
- $aov->{'ms_b'} : between-groups or treatment mean squares
- $aov->{'ms_w'} : within-groups or error mean squares
+ $aov->{'df_b'} : between-groups/treatment/numerator degree(s) of freedom
+ $aov->{'df_w'} : within-groups/error/denominator degree(s) of freedom (also given with F-equivalent Friedman test)
+ $aov->{'ss_b'} : between-groups/treatment sum of squares
+ $aov->{'ss_w'} : within-groups/error sum of squares
+ $aov->{'ms_b'} : between-groups/treatment mean squares
+ $aov->{'ms_w'} : within-groups/error mean squares
 
 =cut
 
@@ -784,10 +776,10 @@ sub anova {
             }
             else {
                 if ( $args{'ordinal'} == 1 ) {    # don't need to calculate ss_b
-                    $self->_aov_indep_param_ord_linear( $data, %args );
+                    $self->_aov_indep_param_ord_linear($data);
                 }
                 else {
-                    $self->_aov_indep_param_ord_nonlinear( $data, %args );
+                    $self->_aov_indep_param_ord_nonlinear($data);
                 }
             }
         }
@@ -854,6 +846,7 @@ The statistical attributes now within the class object (see L<anova|anova>) pert
 
 sub obrien {
     my ( $self, %args ) = @_;
+
     my %data =
       ref $args{'data'} eq 'HASH' ? %{ $args{'data'} } : $self->access();
 
@@ -1448,23 +1441,6 @@ sub confidence {
     }
 
     return scalar( keys(%confints) ) > 1 ? \%confints : $confints{ $names[0] };
-
-=pod
-
-    my $levels = scalar(keys(%{$data}));
-    my $n_comp = $levels * ($levels - 1) / 2;
-    #print "ncomp = $n_comp\n";
-    
-    $alpha /= $n_comp; # divide by number of comparisons
-    my $f_val = fdtri(1, $self->{'_stat'}->{'df_w'}, (.05 / $n_comp ) ); # Math::Cephes fn
-    my $w_var = sqrt($f_val);
-    my $sum = 1;
-    ##$sum +=  1 / $data->{$_}->count foreach keys(%{$data});
-    my $cf = $w_var * sqrt( $self->{'_stat'}->{'ms_w'} * $sum);
-    #print "cf = $cf, f= $f_val, w = $w_var\n";
-
-=cut
-
 }
 
 =head2 ACCESSING RESULTS
@@ -1962,10 +1938,25 @@ sub _init_alpha {
     }
 }
 
+sub _definitely_no {
+    return ( defined $_[0] and $_[0] == 0 ) ? 1 : 0;
+}
+
 1;
 
 __END__
 
+
+=head1 DIAGNOSTICS
+
+=over 4
+
+=item Alpha value should be between 0 and 1, not '$val'.
+
+Initialising an alpha-value for significance-testing was done but not with a valid value; it must be a probablity, but less than 1 and greater than 0.
+
+=back
+
 =head1 REFERENCES
 
 Hollander, M., & Wolfe, D. A. (1999). I<Nonparametric statistical methods>. New York, NY, US: Wiley.
@@ -2000,7 +1991,7 @@ L<Statistics::Sequences|lib::Statistics::Sequences> Offers methods for compariso
 
 L<Statistics::Table::F|Statistics::Table::F> Simply returns an F value. Does not handle missing values, treating them as zero and thus returning an erroneous F-value in these cases.
 
-=head1 BUGS/LIMITATIONS/TO DO
+=head1 BUGS AND LIMITATIONS
 
 Optimisation welcomed.
 
@@ -2018,20 +2009,44 @@ To do: Verbose tracing to check-out what's actually happening internally, what d
 
 See CHANGES in installation distribution.
 
-=head1 AUTHOR/LICENSE
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Statistics::Data
+
+You can also look for information at:
 
 =over 4
 
-=item Copyright (c) 2006-2015 Roderick Garton
+=item * RT: CPAN's request tracker
 
-rgarton AT cpan DOT org
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Statistics-ANOVA-0.091>
 
-This program is free software. It may be used, redistributed and/or modified under the same terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
+=item * AnnoCPAN: Annotated CPAN documentation
 
-=item Disclaimer
+L<http://annocpan.org/dist/Statistics-ANOVA-0.091>
 
-To the maximum extent permitted by applicable law, the author of this module disclaims all warranties, either express or implied, including but not limited to implied warranties of merchantability and fitness for a particular purpose, with regard to the software and the accompanying documentation.
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Statistics-ANOVA-0.091>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Statistics-ANOVA-0.091/>
 
 =back
 
+=head1 AUTHOR
+
+Roderick Garton, C<< <rgarton at cpan.org> >>
+
+=head1 LICENSE AND COPYRIGHT AND DISCLAIMER
+
+Copyright 2006-2015 Roderick Garton
+
+This program is free software. It may be used, redistributed and/or modified under the same terms as Perl-5.6.1 (or later) (see L<http://www.perl.com/perl/misc/Artistic.html>).
+
+To the maximum extent permitted by applicable law, the author of this module disclaims all warranties, either express or implied, including but not limited to implied warranties of merchantability and fitness for a particular purpose, with regard to the software and the accompanying documentation.
+
 =cut
